import setuptools

setuptools.setup(
    name="visonicalarm2",
    version="2.0.6",
    author="Andrea Liosi",
    author_email="andrea.liosi@gmail.com",
    description="A simple API library for the Visonic Alarm system.",
    url="https://github.com/And3rsL/VisonicAlarm-for-Hassio",
    packages=setuptools.find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
)
